pub struct DistanceBounds {
pub lower: Scalar,
pub upper: Scalar,
pub point_a: Point3,
pub point_b: Point3,
}Expand description
An interval certain to contain the distance between two boundaries.
Fields
lower: ScalarNo two boundary points are closer than this.
upper: Scalarpoint_a and point_b are this far apart.
point_a: Point3A point on the first boundary.
point_b: Point3A point on the second boundary, upper from point_a.
Implementations