Struct WindingNumber

pub struct WindingNumber {
    pub value: f64,
    pub skipped_singular_triangles: usize,
}
Raw winding accumulation for one query point.

Fields

value: f64

Sum of oriented triangle solid angles divided by 4π.

skipped_singular_triangles: usize

Faces ignored because the query point was within the supplied linear tolerance of one of their vertices, where their solid angle is undefined.